@@ -20,12 +20,12 @@
 
 using namespace DB;
 
-void MD5Map::insert( const MD5& md5sum, const QString& fileName )
+void MD5Map::insert( const MD5& md5sum, const DB::FileName& fileName )
 {
     _map.insert( md5sum, fileName );
 }
 
-QString MD5Map::lookup( const MD5& md5sum ) const
+DB::FileName MD5Map::lookup( const MD5& md5sum ) const
 {
     return _map[md5sum];
 }
@@ -40,11 +40,11 @@ void MD5Map::clear()
     _map.clear();
 }
 
-StringSet DB::MD5Map::diff( const MD5Map& other ) const
+DB::FileNameSet DB::MD5Map::diff( const MD5Map& other ) const
 {
-    StringSet res;
+    DB::FileNameSet res;
 
-    for( QMap<MD5, QString>::ConstIterator it = _map.begin(); it != _map.end(); ++it ) {
+    for( QMap<MD5, DB::FileName>::ConstIterator it = _map.begin(); it != _map.end(); ++it ) {
         if ( other.lookup( it.key() ) != it.value() )
             res.insert( it.value() );
     }
