@@ -22,20 +22,22 @@
 class QSize;
 class QImage;
 
+namespace DB { class FileName; }
+
 namespace ImageManager
 {
 
 class ImageDecoder {
 public:
-	static bool decode( QImage *img, const QString& imageFile, QSize* fullSize, int dim=-1 );
-	static bool mightDecode( const QString& imageFile );
+    static bool decode( QImage *img, const DB::FileName& imageFile, QSize* fullSize, int dim=-1 );
+    static bool mightDecode( const DB::FileName& imageFile );
 
 	virtual ~ImageDecoder();
 
 protected:
 	ImageDecoder();
-	virtual bool _decode( QImage *img, const QString& imageFile, QSize* fullSize, int dim=-1 ) = 0;
-	virtual bool _mightDecode( const QString& imageFile ) = 0;
+    virtual bool _decode( QImage *img, const DB::FileName& imageFile, QSize* fullSize, int dim=-1 ) = 0;
+    virtual bool _mightDecode( const DB::FileName& imageFile ) = 0;
 
 private:
 	static Q3PtrList<ImageDecoder>* decoders();
