@@ -19,13 +19,12 @@
 #ifndef IMPORTEXPORT_H
 #define IMPORTEXPORT_H
 
-#include "ImageManager/ImageClient.h"
+#include "ImageManager/ImageClientInterface.h"
 #include <KDialog>
 #include "Utilities/UniqFilenameMapper.h"
 #include <QEventLoop>
 #include <QPointer>
-
-namespace DB { class IdList; }
+#include <DB/FileNameList.h>
 
 class QRadioButton;
 class QSpinBox;
@@ -38,12 +37,12 @@ namespace ImportExport
 
 enum ImageFileLocation { Inline, ManualCopy, AutoCopy, Link, Symlink };
 
-class Export :public ImageManager::ImageClient {
+class Export :public ImageManager::ImageClientInterface {
 
 public:
-    static void imageExport(const DB::IdList& list);
+    static void imageExport(const DB::FileNameList& list);
 
-    Export( const DB::IdList& list, const QString& zipFile,
+    Export( const DB::FileNameList& list, const QString& zipFile,
             bool compress, int maxSize,
             ImageFileLocation, const QString& baseUrl,
             bool generateThumbnails,
@@ -53,11 +52,11 @@ public:
     static void showUsageDialog();
 
     // ImageManager::ImageClient callback.
-    virtual void pixmapLoaded( const QString& fileName, const QSize& size, const QSize& fullSize, int angle, const QImage&, const bool loadedOK);
+    virtual void pixmapLoaded( const DB::FileName& fileName, const QSize& size, const QSize& fullSize, int angle, const QImage&, const bool loadedOK);
 
 protected:
-    void generateThumbnails(const DB::IdList& list);
-    void copyImages(const DB::IdList& list);
+    void generateThumbnails(const DB::FileNameList& list);
+    void copyImages(const DB::FileNameList& list);
 
 private:
     bool* _ok;
