@@ -22,13 +22,13 @@
 #include <QResizeEvent>
 #include <QMouseEvent>
 #include <QPaintEvent>
-#include "ImageManager/ImageClient.h"
+#include "ImageManager/ImageClientInterface.h"
 #include <qimage.h>
 #include <q3ptrvector.h>
 #include "DB/ImageInfoPtr.h"
-#include "Display.h"
+#include "AbstractDisplay.h"
 #include "Settings/SettingsData.h"
-
+#include <DB/FileNameList.h>
 class QTimer;
 
 namespace DB
@@ -50,14 +50,14 @@ struct ViewPreloadInfo
     int angle;
 };
 
-class ImageDisplay :public Viewer::Display, public ImageManager::ImageClient {
+class ImageDisplay :public Viewer::AbstractDisplay, public ImageManager::ImageClientInterface {
 Q_OBJECT
 public:
     ImageDisplay( QWidget* parent );
     bool setImage( DB::ImageInfoPtr info, bool forward );
     QImage currentViewAsThumbnail() const;
-    virtual void pixmapLoaded( const QString& fileName, const QSize& size, const QSize& fullSize, int angle, const QImage&, const bool loadedOK);
-    void setImageList( const QStringList& list );
+    virtual void pixmapLoaded( const DB::FileName& fileName, const QSize& size, const QSize& fullSize, int angle, const QImage&, const bool loadedOK);
+    void setImageList( const DB::FileNameList& list );
 
     void filterNone();
     void filterSelected();
@@ -95,7 +95,7 @@ protected:
     void xformPainter( QPainter* );
     void cropAndScale();
     void updatePreload();
-    int indexOf( const QString& fileName );
+    int indexOf( const DB::FileName& fileName );
     void requestImage( const DB::ImageInfoPtr& info, bool priority = false );
 
     /** display zoom factor in title of display window */
@@ -124,7 +124,7 @@ private:
     QPoint _zEnd;
 
     Q3PtrVector<ViewPreloadInfo> _cache;
-    QStringList _imageList;
+    DB::FileNameList _imageList;
     QMap<QString, DB::ImageInfoPtr> _loadMap;
     bool _reloadImageInProgress;
     int _forward;
